@@ -93,7 +93,6 @@
 "receptive_train"
 
 
-
 #' Pre-Trained Receptiveness Data
 #'
 #' A dataset to train a model for detecting conversational receptiveness.
@@ -101,6 +100,17 @@
 #'
 "receptive_polite"
 
+#' Pre-Trained Politeness
+#'
+#' A dataset to train a model for detecting politeness.
+#'
+#' @source Danescu-Niculescu-Mizil, C., Sudhof, M., Jurafsky, D., Leskovec, J. & Potts, C. (2013). A computational approach to politeness with application to social factors. Proc. 51st ACL, 250-259.
+#'
+#' @format list of two objects. x contains pre-calculated politeness features for each document. y contains standardized human annotations for politeness.
+#'
+"polite_train"
+
+
 #' UK to US Conversion dictionary
 #'
 #' For internal use only. This dataset contains a quanteda dictionary for converting UK words to US words. The models in this package were all trained on US English.
